# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'simsapa/assets/ui/notes_browser_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_NotesBrowserWindow(object):
    def setupUi(self, NotesBrowserWindow):
        NotesBrowserWindow.setObjectName("NotesBrowserWindow")
        NotesBrowserWindow.resize(856, 581)
        NotesBrowserWindow.setBaseSize(QtCore.QSize(800, 600))
        self.central_widget = QtWidgets.QWidget(NotesBrowserWindow)
        self.central_widget.setObjectName("central_widget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.central_widget)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.main_layout = QtWidgets.QVBoxLayout()
        self.main_layout.setObjectName("main_layout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.central_widget)
        self.label.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.front_input = QtWidgets.QPlainTextEdit(self.central_widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.front_input.sizePolicy().hasHeightForWidth())
        self.front_input.setSizePolicy(sizePolicy)
        self.front_input.setMinimumSize(QtCore.QSize(0, 50))
        self.front_input.setMaximumSize(QtCore.QSize(16777215, 50))
        self.front_input.setObjectName("front_input")
        self.verticalLayout.addWidget(self.front_input)
        self.label_2 = QtWidgets.QLabel(self.central_widget)
        self.label_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.back_input = QtWidgets.QPlainTextEdit(self.central_widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.back_input.sizePolicy().hasHeightForWidth())
        self.back_input.setSizePolicy(sizePolicy)
        self.back_input.setMinimumSize(QtCore.QSize(0, 50))
        self.back_input.setMaximumSize(QtCore.QSize(16777215, 50))
        self.back_input.setObjectName("back_input")
        self.verticalLayout.addWidget(self.back_input)
        self.main_layout.addLayout(self.verticalLayout)
        self.searchbar_layout = QtWidgets.QHBoxLayout()
        self.searchbar_layout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.searchbar_layout.setObjectName("searchbar_layout")
        self.search_input = QtWidgets.QLineEdit(self.central_widget)
        self.search_input.setMinimumSize(QtCore.QSize(0, 35))
        self.search_input.setClearButtonEnabled(True)
        self.search_input.setObjectName("search_input")
        self.searchbar_layout.addWidget(self.search_input)
        self.search_button = QtWidgets.QPushButton(self.central_widget)
        self.search_button.setMinimumSize(QtCore.QSize(0, 40))
        self.search_button.setObjectName("search_button")
        self.searchbar_layout.addWidget(self.search_button)
        self.main_layout.addLayout(self.searchbar_layout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.notes_list = QtWidgets.QListView(self.central_widget)
        self.notes_list.setObjectName("notes_list")
        self.verticalLayout_2.addWidget(self.notes_list)
        self.main_layout.addLayout(self.verticalLayout_2)
        self.horizontalLayout_2.addLayout(self.main_layout)
        NotesBrowserWindow.setCentralWidget(self.central_widget)
        self.menubar = QtWidgets.QMenuBar(NotesBrowserWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 856, 20))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menu_Edit = QtWidgets.QMenu(self.menubar)
        self.menu_Edit.setObjectName("menu_Edit")
        self.menu_Windows = QtWidgets.QMenu(self.menubar)
        self.menu_Windows.setObjectName("menu_Windows")
        self.menu_Help = QtWidgets.QMenu(self.menubar)
        self.menu_Help.setObjectName("menu_Help")
        self.menu_Notes = QtWidgets.QMenu(self.menubar)
        self.menu_Notes.setObjectName("menu_Notes")
        NotesBrowserWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(NotesBrowserWindow)
        self.statusbar.setObjectName("statusbar")
        NotesBrowserWindow.setStatusBar(self.statusbar)
        self.toolBar_2 = QtWidgets.QToolBar(NotesBrowserWindow)
        self.toolBar_2.setObjectName("toolBar_2")
        NotesBrowserWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_2)
        self.action_Copy = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Copy.setObjectName("action_Copy")
        self.action_Paste = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Paste.setObjectName("action_Paste")
        self.action_Quit = QtWidgets.QAction(NotesBrowserWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/close"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Quit.setIcon(icon)
        self.action_Quit.setObjectName("action_Quit")
        self.action_Sutta_Search = QtWidgets.QAction(NotesBrowserWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/book"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Sutta_Search.setIcon(icon1)
        self.action_Sutta_Search.setObjectName("action_Sutta_Search")
        self.action_Dictionary_Search = QtWidgets.QAction(NotesBrowserWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/dictionary"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Dictionary_Search.setIcon(icon2)
        self.action_Dictionary_Search.setObjectName("action_Dictionary_Search")
        self.action_About = QtWidgets.QAction(NotesBrowserWindow)
        self.action_About.setObjectName("action_About")
        self.action_Website = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Website.setObjectName("action_Website")
        self.action_Close_Window = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Close_Window.setObjectName("action_Close_Window")
        self.action_Open = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Open.setObjectName("action_Open")
        self.action_Document_Reader = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Document_Reader.setObjectName("action_Document_Reader")
        self.action_Add = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Add.setObjectName("action_Add")
        self.action_Remove = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Remove.setObjectName("action_Remove")
        self.action_Open_Selected = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Open_Selected.setObjectName("action_Open_Selected")
        self.action_Library = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Library.setObjectName("action_Library")
        self.action_Sync_to_Anki = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Sync_to_Anki.setObjectName("action_Sync_to_Anki")
        self.action_Notes = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Notes.setObjectName("action_Notes")
        self.action_Dictionaries_Manager = QtWidgets.QAction(NotesBrowserWindow)
        self.action_Dictionaries_Manager.setObjectName("action_Dictionaries_Manager")
        self.menu_File.addAction(self.action_Open)
        self.menu_File.addAction(self.action_Close_Window)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Quit)
        self.menu_Edit.addAction(self.action_Copy)
        self.menu_Edit.addAction(self.action_Paste)
        self.menu_Windows.addAction(self.action_Sutta_Search)
        self.menu_Windows.addAction(self.action_Dictionary_Search)
        self.menu_Windows.addAction(self.action_Dictionaries_Manager)
        self.menu_Windows.addAction(self.action_Document_Reader)
        self.menu_Windows.addAction(self.action_Library)
        self.menu_Windows.addAction(self.action_Notes)
        self.menu_Help.addAction(self.action_Website)
        self.menu_Help.addAction(self.action_About)
        self.menu_Notes.addAction(self.action_Sync_to_Anki)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Edit.menuAction())
        self.menubar.addAction(self.menu_Windows.menuAction())
        self.menubar.addAction(self.menu_Notes.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar_2.addAction(self.action_Add)
        self.toolBar_2.addAction(self.action_Remove)
        self.toolBar_2.addAction(self.action_Sync_to_Anki)

        self.retranslateUi(NotesBrowserWindow)
        QtCore.QMetaObject.connectSlotsByName(NotesBrowserWindow)

    def retranslateUi(self, NotesBrowserWindow):
        _translate = QtCore.QCoreApplication.translate
        NotesBrowserWindow.setWindowTitle(_translate("NotesBrowserWindow", "Notes - Simsapa"))
        self.label.setText(_translate("NotesBrowserWindow", "Front"))
        self.label_2.setText(_translate("NotesBrowserWindow", "Back"))
        self.search_button.setText(_translate("NotesBrowserWindow", "Search"))
        self.menu_File.setTitle(_translate("NotesBrowserWindow", "&File"))
        self.menu_Edit.setTitle(_translate("NotesBrowserWindow", "&Edit"))
        self.menu_Windows.setTitle(_translate("NotesBrowserWindow", "&Windows"))
        self.menu_Help.setTitle(_translate("NotesBrowserWindow", "&Help"))
        self.menu_Notes.setTitle(_translate("NotesBrowserWindow", "&Notes"))
        self.toolBar_2.setWindowTitle(_translate("NotesBrowserWindow", "toolBar_2"))
        self.action_Copy.setText(_translate("NotesBrowserWindow", "&Copy"))
        self.action_Paste.setText(_translate("NotesBrowserWindow", "&Paste"))
        self.action_Quit.setText(_translate("NotesBrowserWindow", "&Quit"))
        self.action_Quit.setShortcut(_translate("NotesBrowserWindow", "Ctrl+Q"))
        self.action_Sutta_Search.setText(_translate("NotesBrowserWindow", "&Sutta Search"))
        self.action_Sutta_Search.setShortcut(_translate("NotesBrowserWindow", "F5"))
        self.action_Dictionary_Search.setText(_translate("NotesBrowserWindow", "&Dictionary Search"))
        self.action_Dictionary_Search.setShortcut(_translate("NotesBrowserWindow", "F6"))
        self.action_About.setText(_translate("NotesBrowserWindow", "&About"))
        self.action_Website.setText(_translate("NotesBrowserWindow", "&Website"))
        self.action_Close_Window.setText(_translate("NotesBrowserWindow", "&Close Window"))
        self.action_Open.setText(_translate("NotesBrowserWindow", "&Open..."))
        self.action_Open.setShortcut(_translate("NotesBrowserWindow", "Ctrl+O"))
        self.action_Document_Reader.setText(_translate("NotesBrowserWindow", "D&ocument Reader"))
        self.action_Document_Reader.setToolTip(_translate("NotesBrowserWindow", "Document Reader"))
        self.action_Document_Reader.setShortcut(_translate("NotesBrowserWindow", "F7"))
        self.action_Add.setText(_translate("NotesBrowserWindow", "&Add..."))
        self.action_Remove.setText(_translate("NotesBrowserWindow", "&Remove"))
        self.action_Remove.setShortcut(_translate("NotesBrowserWindow", "Del"))
        self.action_Open_Selected.setText(_translate("NotesBrowserWindow", "&Open Selected"))
        self.action_Library.setText(_translate("NotesBrowserWindow", "&Library"))
        self.action_Library.setShortcut(_translate("NotesBrowserWindow", "F8"))
        self.action_Sync_to_Anki.setText(_translate("NotesBrowserWindow", "&Sync to Anki"))
        self.action_Notes.setText(_translate("NotesBrowserWindow", "&Notes"))
        self.action_Notes.setToolTip(_translate("NotesBrowserWindow", "Notes"))
        self.action_Notes.setShortcut(_translate("NotesBrowserWindow", "F9"))
        self.action_Dictionaries_Manager.setText(_translate("NotesBrowserWindow", "Dictionaries &Manager"))
        self.action_Dictionaries_Manager.setShortcut(_translate("NotesBrowserWindow", "F10"))
from simsapa.assets import icons_rc
